@@ -385,7 +385,7 @@ impl App {
 			self.compare_commits_popup.update_git(ev)?;
 			self.push_popup.update_git(ev)?;
 			self.push_tags_popup.update_git(ev)?;
-			self.pull_popup.update_git(ev)?;
+			self.pull_popup.update_git(ev);
 			self.select_branch_popup.update_git(ev)?;
 		}
 
@@ -686,7 +686,11 @@ impl App {
 				flags.insert(NeedsUpdate::ALL);
 			}
 			InternalEvent::Pull(branch) => {
-				self.pull_popup.fetch(branch)?;
+				if let Err(error) = self.pull_popup.fetch(branch) {
+					self.queue.push(InternalEvent::ShowErrorMsg(
+						error.to_string(),
+					));
+				}
 				flags.insert(NeedsUpdate::ALL);
 			}
 			InternalEvent::PushTags => {
@@ -776,19 +780,21 @@ impl App {
 			}
 			Action::DeleteBranch(branch_ref, false) => {
 				self.queue.push(
-					if let Some(name) = branch_ref.rsplit('/').next()
-					{
-						InternalEvent::Push(
-							name.to_string(),
-							false,
-							true,
-						)
-					} else {
-						InternalEvent::ShowErrorMsg(format!(
-							"Failed to find the branch name in {}",
-							branch_ref
-						))
-					},
+					branch_ref.rsplit('/').next().map_or_else(
+						|| {
+							InternalEvent::ShowErrorMsg(format!(
+						"Failed to find the branch name in {}",
+						branch_ref
+					))
+						},
+						|name| {
+							InternalEvent::Push(
+								name.to_string(),
+								false,
+								true,
+							)
+						},
+					),
 				);
 				flags.insert(NeedsUpdate::ALL);
 				self.select_branch_popup.update_branches()?;
@@ -815,6 +821,10 @@ impl App {
 				self.status_tab.abort_merge();
 				flags.insert(NeedsUpdate::ALL);
 			}
+			Action::AbortRebase => {
+				self.status_tab.abort_rebase();
+				flags.insert(NeedsUpdate::ALL);
+			}
 		};
 
 		Ok(())
