@@ -200,6 +200,10 @@ impl ConfirmComponent {
                 Action::AbortMerge => (
                     strings::confirm_title_abortmerge(),
                     strings::confirm_msg_abortmerge(),
+                ),
+				Action::AbortRebase => (
+                    strings::confirm_title_abortrebase(),
+                    strings::confirm_msg_abortrebase(),
                 ),
             };
 		}
